class UrlConsts:
    """
    Centralized location for all service URLs used in the application.
    """
    AZCOPY_API_URL: str = "http://infinity-serivces.westeurope.cloudapp.azure.com:8080/send_to_azcopy"

    TGV_API_URL: str = "http://infinity-serivces.westeurope.cloudapp.azure.com:8080/tgv_process"

    WALL_E_SOLUTION_SKYLINE_SERVICE: str = 'https://pmapi.skylineglobe.com/startproject/Mipui/poda/a247acd3-977c-4a77-b93f-e713a8632d57'

    WAR_E_SOLUTION_SKYLINE_SERVICE: str = 'https://pmapi.skylineglobe.com/startproject/Mipui/podb/a247acd3-977c-4a77-b93f-e713a8632d57'


from setuptools import find_packages, setup

setup(
    name='infi_const',
    packages=find_packages(),
    version='0.0.11',
    description='Const package for infinity team',
    author='Infinity Team',
    install_requires=[],
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
)


class UtilsConsts:
    EMAIL_LIST_NAVAD: list[str] = ["liorfranko587@gmail.com, amit.shwartz01@gmail.com, itay@skylinesoft.com,\
                            ronik1917@gmail.com, Daniel@iit.co.il, Bason_tehila@hotmail.com,\
                            Ronnie@skylinesoft.com, liorcliorc@gmail.com, razraz2711@gmail.com,\
                            shmuelmorr@gmail.com, shacharba@matrix.co.il, stamdvarim1000@gmail.com,\
                            Rotembh20000@gmail.com"]

    EMAIL_TEST_LIST: list[str] = ["infinitymailbox9900@gmail.com,stamdvarim1000@gmail.com"]

    AZCOPY_QUEUE: str = "azcopy_q"

    FLIGHTS_RECORD_QUEUE: str = "flights_record_q"

    FLIGHTS_HISTORY_QUEUE: str = "flights_history_q"

    FLIGHTS_RECORD_SKYLINE_COLUMN: str = "SkylineInit"

    TGV_VALIDATIONS_QUEUE: str = "tgv_q"

    PREPROCESS_QUEUE: str = "pre_q"

    FAILED_FLIGHTS_RECORD_QUEUE: str = "failed_flights_record_q"

    FAILED_FLIGHTS_HISTORY_QUEUE: str = "failed_flights_history_q"

    FAILED_TGV_VALIDATIONS_QUEUE: str = "failed_tgv_q"

    FAILED_PREPROCESS_QUEUE: str = "failed_pre_q"

    FAILED_AZCOPY_QUEUE: str = "failed_azcopy_q"

    API_PORT: int = 8080

    STATUS_LIST: list = ["DMZ", "SkylineInit", "AT", "Mesh", "Upload"]

    COLUMNS_DB: list = [
        "NAME",
        "TYPE_GIHA",
        "DAY",
        "MONTH",
        "YEAR",
        "OVERLAP",
        "TAIL_NUMBER",
        "PAYLOAD_NUMBER",
        "PAYLOAD_DIGITS",
        "FLIGHT_NUMBER",
        "NUM_PIC",
    ]
